@@ -264,6 +264,7 @@ void MainWindow::UpdateFlashInterfaceAvailability(void)
 		startFlashButton->setEnabled(validFlashSettings);
 		noRebootCheckBox->setEnabled(validFlashSettings);
 		resumeCheckbox->setEnabled(validFlashSettings);
+		waitForDeviceCheckbox->setEnabled(validFlashSettings);
 	}
 	else
 	{
@@ -398,6 +399,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
 	verboseOutput = false;
 	resume = false;
+	waitForDevice = false;
 
 	tabIndex = functionTabWidget->currentIndex();
 	functionTabWidget->setTabEnabled(functionTabWidget->indexOf(createPackageTab), false);
@@ -405,7 +407,6 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 	QObject::connect(functionTabWidget, SIGNAL(currentChanged(int)), this, SLOT(FunctionTabChanged(int)));
 	
 	// Menu
-	QObject::connect(actionDonate, SIGNAL(triggered()), this, SLOT(OpenDonationWebpage()));
 	QObject::connect(actionVerboseOutput, SIGNAL(toggled(bool)), this, SLOT(SetVerboseOutput(bool)));
 	QObject::connect(actionResumeConnection, SIGNAL(toggled(bool)), this, SLOT(SetResume(bool)));
 	QObject::connect(actionAboutHeimdall, SIGNAL(triggered()), this, SLOT(ShowAbout()));
@@ -430,6 +431,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
 	QObject::connect(noRebootCheckBox, SIGNAL(stateChanged(int)), this, SLOT(SetNoReboot(int)));
 	QObject::connect(resumeCheckbox, SIGNAL(stateChanged(int)), this, SLOT(SetResume(int)));
+	QObject::connect(waitForDeviceCheckbox, SIGNAL(stateChanged(int)), this, SLOT(SetWaitForDevice(int)));
 	
 	QObject::connect(startFlashButton, SIGNAL(clicked()), this, SLOT(StartFlash()));
 
@@ -481,7 +483,7 @@ MainWindow::~MainWindow()
 
 void MainWindow::OpenDonationWebpage(void)
 {
-	QDesktopServices::openUrl(QUrl("http://www.glassechidna.com.au/donate/", QUrl::StrictMode));
+	QDesktopServices::openUrl(QUrl("https://www.glassechidna.com.au/donate/", QUrl::StrictMode));
 }
 
 void MainWindow::SetVerboseOutput(bool enabled)
@@ -900,6 +902,17 @@ void MainWindow::SetResume(int enabled)
 	SetResume(enabled != 0);
 }
 
+void MainWindow::SetWaitForDevice(bool enabled)
+{
+	waitForDevice = enabled;
+	waitForDeviceCheckbox->setChecked(enabled);
+}
+
+void MainWindow::SetWaitForDevice(int enabled)
+{
+	SetWaitForDevice(enabled != 0);
+}
+
 void MainWindow::StartFlash(void)
 {
 	outputPlainTextEdit->clear();
@@ -936,6 +949,9 @@ void MainWindow::StartFlash(void)
 	if (resume)
 		arguments.append("--resume");
 
+	if (waitForDevice)
+		arguments.append("--wait");
+
 	if (verboseOutput)
 		arguments.append("--verbose");
 
@@ -1089,6 +1105,9 @@ void MainWindow::DetectDevice(void)
 	QStringList arguments;
 	arguments.append("detect");
 
+	if (waitForDevice)
+		arguments.append("--wait");
+
 	if (verboseOutput)
 		arguments.append("--verbose");
 
@@ -1110,6 +1129,9 @@ void MainWindow::ClosePcScreen(void)
 	if (resume)
 		arguments.append("--resume");
 
+	if (waitForDevice)
+		arguments.append("--wait");
+
 	if (verboseOutput)
 		arguments.append("--verbose");
 
@@ -1152,6 +1174,9 @@ void MainWindow::DownloadPit(void)
 	if (resume)
 		arguments.append("--resume");
 
+	if (waitForDevice)
+		arguments.append("--wait");
+
 	if (verboseOutput)
 		arguments.append("--verbose");
 
