@@ -33,9 +33,10 @@ using namespace Heimdall;
 
 const char *DownloadPitAction::usage = "Action: download-pit\n\
 Arguments: --output <filename> [--verbose] [--no-reboot] [--stdout-errors]\n\
-    [--usb-log-level <none/error/warning/debug>]\n\
+    [--wait] [--usb-log-level <none/error/warning/debug>]\n\
 Description: Downloads the connected device's PIT file to the specified\n\
-    output file.\n\
+    output file. If --wait is used Heimdall waits until a compatible device is\n\
+    connected.\n\
 Note: --no-reboot causes the device to remain in download mode after the action\n\
       is completed. If you wish to perform another action whilst remaining in\n\
       download mode, then the following action must specify the --resume flag.\n";
@@ -49,6 +50,7 @@ int DownloadPitAction::Execute(int argc, char **argv)
 	argumentTypes["no-reboot"] = kArgumentTypeFlag;
 	argumentTypes["resume"] = kArgumentTypeFlag;
 	argumentTypes["verbose"] = kArgumentTypeFlag;
+	argumentTypes["wait"] = kArgumentTypeFlag;
 	argumentTypes["stdout-errors"] = kArgumentTypeFlag;
 	argumentTypes["usb-log-level"] = kArgumentTypeString;
 
@@ -69,10 +71,11 @@ int DownloadPitAction::Execute(int argc, char **argv)
 		return (0);
 	}
 
+	bool waitForDevice = arguments.GetArgument("wait") == nullptr;
 	bool reboot = arguments.GetArgument("no-reboot") == nullptr;
 	bool resume = arguments.GetArgument("resume") != nullptr;
 	bool verbose = arguments.GetArgument("verbose") != nullptr;
-	
+
 	if (arguments.GetArgument("stdout-errors") != nullptr)
 		Interface::SetStdoutErrors(true);
 
@@ -130,7 +133,7 @@ int DownloadPitAction::Execute(int argc, char **argv)
 
 	// Download PIT file from device.
 
-	BridgeManager *bridgeManager = new BridgeManager(verbose);
+	BridgeManager *bridgeManager = new BridgeManager(verbose, waitForDevice);
 	bridgeManager->SetUsbLogLevel(usbLogLevel);
 
 	if (bridgeManager->Initialise(resume) != BridgeManager::kInitialiseSucceeded || !bridgeManager->BeginSession())
