@@ -1,4 +1,4 @@
-/* Copyright (c) 2010-2014 Benjamin Dobell, Glass Echidna
+/* Copyright (c) 2010-2017 Benjamin Dobell, Glass Echidna
  
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
@@ -28,7 +28,7 @@ using namespace Heimdall;
 const char *HelpAction::usage = "Action: help\n\
 Description: Displays this dialogue.\n";
 
-int HelpAction::Execute(int argc, char **argv)
+int HelpAction::Execute(__attribute__((unused)) int argc, __attribute__((unused)) char **argv)
 {
 	Interface::PrintUsage();
 	return (0);
